@@ -1,21 +1,21 @@
 class Anonymous(object):
-    def ID(message):
+    def id(message):
         return message.from_user.id if message.from_user else None
 
-    def FIRST(message):
+    def first(message):
       return message.from_user.first_name if message.from_user else None
 
-    def LAST(message):
+    def last(message):
       return message.from_user.last_name  if message.from_user else None
 
-    def USERNAME(message):
+    def username(message):
       return message.from_user.username  if message.from_user else None
 
-    def LANG_CODE(message):
+    def lang_code(message):
       return message.from_user.language_code if message.from_user else None
 
-    def DC_ID(message):
+    def dc_id(message):
       return message.from_user.dc_id if message.from_user else None
 
-    def MENTION(message):
+    def mention(message):
       return message.from_user.mention if message.from_user else None
